@@ -34,7 +34,7 @@
 #' The model can be created using the `fit()` function using the
 #'  following _engines_:
 #' \itemize{
-#' \item \pkg{R}:  `"rpart"` or `"C5.0"` (classification only)
+#' \item \pkg{R}:  `"rpart"` (the default) or `"C5.0"` (classification only)
 #' \item \pkg{Spark}: `"spark"`
 #' }
 #'
@@ -115,7 +115,7 @@ print.decision_tree <- function(x, ...) {
   cat("Decision Tree Model Specification (", x$mode, ")\n\n", sep = "")
   model_printer(x, ...)
 
-  if(!is.null(x$method$fit$args)) {
+  if (!is.null(x$method$fit$args)) {
     cat("Model fit template:\n")
     print(show_call(x))
   }
@@ -171,8 +171,8 @@ update.decision_tree <-
 #' @export
 translate.decision_tree <- function(x, engine = x$engine, ...) {
   if (is.null(engine)) {
-    message("Used `engine = 'ranger'` for translation.")
-    engine <- "ranger"
+    message("Used `engine = 'rpart'` for translation.")
+    engine <- "rpart"
   }
 
   x <- translate.default(x, engine, ...)
@@ -183,36 +183,13 @@ translate.decision_tree <- function(x, engine = x$engine, ...) {
   if (x$engine == "spark") {
     if (x$mode == "unknown") {
       stop(
-        "For spark random forests models, the mode cannot be 'unknown' ",
+        "For spark decision tree models, the mode cannot be 'unknown' ",
         "if the specification is to be translated.",
         call. = FALSE
       )
-    } else {
-      arg_vals$type <- x$mode
-    }
-
-    # See "Details" in ?ml_random_forest_classifier. `feature_subset_strategy`
-    # should be character even if it contains a number.
-    if (any(names(arg_vals) == "feature_subset_strategy") &&
-        isTRUE(is.numeric(quo_get_expr(arg_vals$feature_subset_strategy)))) {
-      arg_vals$feature_subset_strategy <-
-        paste(quo_get_expr(arg_vals$feature_subset_strategy))
     }
   }
 
-  # add checks to error trap or change things for this method
-  if (engine == "ranger") {
-    if (any(names(arg_vals) == "importance"))
-      if (isTRUE(is.logical(quo_get_expr(arg_vals$importance))))
-        stop("`importance` should be a character value. See ?ranger::ranger.",
-             call. = FALSE)
-    # unless otherwise specified, classification models are probability forests
-    if (x$mode == "classification" && !any(names(arg_vals) == "probability"))
-      arg_vals$probability <- TRUE
-
-  }
-  x$method$fit$args <- arg_vals
-
   x
 }
 
@@ -252,6 +229,7 @@ check_args.decision_tree <- function(object) {
 #'  those cases.
 #' @param ... Other arguments to pass to either `rpart` or `rpart.control`.
 #' @return A fitted rpart model.
+#' @keywords internal
 #' @export
 rpart_train <-
   function(formula, data, weights = NULL, cp = 0.01, minsplit = 20, maxdepth = 30, ...) {
@@ -272,18 +250,16 @@ rpart_train <-
     ctrl$minsplit <- minsplit
     ctrl$maxdepth <- maxdepth
     ctrl$cp <- cp
-    for(i in names(ctrl_args))
-      ctrl[[i]] <- ctrl_args[[i]]
+    ctrl <- rlang::call_modify(ctrl, !!!ctrl_args)
 
     fit_call <- call2("rpart", .ns = "rpart")
     fit_call$formula <- expr(formula)
     fit_call$data <- expr(data)
     fit_call$control <- ctrl
-    if(!is.null(weights))
+    if (!is.null(weights)) {
       fit_call$weights <- quote(weights)
-
-    for(i in names(fit_args))
-      fit_call[[i]] <- fit_args[[i]]
+    }
+    fit_call <- rlang::call_modify(fit_call, !!!fit_args)
 
     eval_tidy(fit_call)
   }
