@@ -34,7 +34,7 @@
 #' The model can be created using the `fit()` function using the
 #'  following _engines_:
 #' \itemize{
-#' \item \pkg{R}:  `"glm"` or `"glmnet"`
+#' \item \pkg{R}:  `"glm"`  (the default) or `"glmnet"`
 #' \item \pkg{Stan}:  `"stan"`
 #' \item \pkg{Spark}: `"spark"`
 #' \item \pkg{keras}: `"keras"`
@@ -66,9 +66,9 @@
 #'
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::logistic_reg(), "keras")}
 #'
-#' When using `glmnet` models, there is the option to pass
-#'  multiple values (or no values) to the `penalty` argument. This
-#'  can have an effect on the model object results. When using the
+#' For `glmnet` models, the full regularization path is always fit regardless
+#' of the value given to `penalty`. Also, there is the option to pass
+#'  multiple values (or no values) to the `penalty` argument. When using the
 #'  `predict()` method in these cases, the return value depends on
 #'  the value of `penalty`. When using `predict()`, only a single
 #'  value of the penalty can be used. When predicting on multiple
@@ -137,6 +137,9 @@ print.logistic_reg <- function(x, ...) {
   invisible(x)
 }
 
+#' @export
+translate.logistic_reg <- translate.linear_reg
+
 # ------------------------------------------------------------------------------
 
 #' @inheritParams update.boost_tree
@@ -235,7 +238,7 @@ organize_glmnet_prob <- function(x, object) {
 }
 
 # ------------------------------------------------------------------------------
-# glmnet call stack for linear regression using `predict` when object has
+# glmnet call stack for logistic regression using `predict` when object has
 # classes "_lognet" and "model_fit" (for class predictions):
 #
 #  predict()
@@ -247,7 +250,7 @@ organize_glmnet_prob <- function(x, object) {
 #        predict.lognet()
 
 
-# glmnet call stack for linear regression using `multi_predict` when object has
+# glmnet call stack for logistic regression using `multi_predict` when object has
 # classes "_lognet" and "model_fit" (for class predictions):
 #
 # 	multi_predict()
@@ -262,10 +265,15 @@ organize_glmnet_prob <- function(x, object) {
 # ------------------------------------------------------------------------------
 
 #' @export
-predict._lognet <- function (object, new_data, type = NULL, opts = list(), penalty = NULL, multi = FALSE, ...) {
+predict._lognet <- function(object, new_data, type = NULL, opts = list(), penalty = NULL, multi = FALSE, ...) {
   if (any(names(enquos(...)) == "newdata"))
     stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
 
+  # See discussion in https://github.com/tidymodels/parsnip/issues/195
+  if (is.null(penalty) & !is.null(object$spec$args$penalty)) {
+    penalty <- object$spec$args$penalty
+  }
+
   object$spec$args$penalty <- check_penalty(penalty, object, multi)
 
   object$spec <- eval_args(object$spec)
@@ -276,6 +284,7 @@ predict._lognet <- function (object, new_data, type = NULL, opts = list(), penal
 #' @importFrom dplyr full_join as_tibble arrange
 #' @importFrom tidyr gather
 #' @export
+#' @rdname multi_predict
 multi_predict._lognet <-
   function(object, new_data, type = NULL, penalty = NULL, ...) {
     if (any(names(enquos(...)) == "newdata"))
@@ -285,8 +294,16 @@ multi_predict._lognet <-
       penalty <- eval_tidy(penalty)
 
     dots <- list(...)
-    if (is.null(penalty))
-      penalty <- eval_tidy(object$fit$lambda)
+
+    if (is.null(penalty)) {
+      # See discussion in https://github.com/tidymodels/parsnip/issues/195
+      if (!is.null(object$spec$args$penalty)) {
+        penalty <- object$spec$args$penalty
+      } else {
+        penalty <- object$fit$lambda
+      }
+    }
+
     dots$s <- penalty
 
     if (is.null(type))
@@ -329,7 +346,7 @@ multi_predict._lognet <-
 
 
 #' @export
-predict_class._lognet <- function (object, new_data, ...) {
+predict_class._lognet <- function(object, new_data, ...) {
   if (any(names(enquos(...)) == "newdata"))
     stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
 
@@ -338,7 +355,7 @@ predict_class._lognet <- function (object, new_data, ...) {
 }
 
 #' @export
-predict_classprob._lognet <- function (object, new_data, ...) {
+predict_classprob._lognet <- function(object, new_data, ...) {
   if (any(names(enquos(...)) == "newdata"))
     stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
 
@@ -347,7 +364,7 @@ predict_classprob._lognet <- function (object, new_data, ...) {
 }
 
 #' @export
-predict_raw._lognet <- function (object, new_data, opts = list(), ...) {
+predict_raw._lognet <- function(object, new_data, opts = list(), ...) {
   if (any(names(enquos(...)) == "newdata"))
     stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
 
@@ -358,5 +375,7 @@ predict_raw._lognet <- function (object, new_data, opts = list(), ...) {
 
 # ------------------------------------------------------------------------------
 
-#' @importFrom utils globalVariables
-utils::globalVariables(c("group", ".pred"))
+#' @export
+#' @export min_grid.logistic_reg
+#' @rdname min_grid
+min_grid.logistic_reg <- min_grid.linear_reg
