@@ -36,6 +36,9 @@ test_that('spark execution', {
     regexp = NA
   )
 
+  expect_false(has_multi_predict(spark_fit))
+  expect_equal(multi_predict_args(spark_fit), NA_character_)
+
   expect_error(
     spark_pred <- predict(spark_fit, iris_linreg_te),
     regexp = NA
